@@ -33,8 +33,9 @@ function rilDownloadList() {
     var xhr = new XMLHttpRequest;
     var params = rilGetParams();
     //console.log(params);
-    var url="http://readitlaterlist.com/v2/get";
+    var url="https://readitlaterlist.com/v2/get";
     var since=Storage.getSetting("rilLastUpdate");
+    params = params + "&state=unread"
     if (since!="Unknown") {
         params = params+"&since="+since;
     }
@@ -59,7 +60,9 @@ function rilDownloadList() {
                     //console.log(o.title);
                     //var status = Storage.getDownloadedStatus(o.url)
                     //if ((status=="Unknown") || (currentArticle=="Not downloaded yet")) {
-                    Storage.saveRilArticle(changeAmpersand(o.url), changeAmpersand(o.title), "Not downloaded yet", o.state)
+
+                    //Storage.saveRilArticle(changeAmpersand(o.url), changeAmpersand(o.title), "Not downloaded yet", o.state)
+                    Storage.saveRilArticle(o.url, o.title, "Not downloaded yet", o.state)
                     //    rilDownloadRilArticle(o.url);
                     //}
                     articleViewer.refreshList();
@@ -86,7 +89,7 @@ function rilDownloadRilArticle(articleUrl) {
     var xhr = new XMLHttpRequest;
 
     var params = "apikey=" + Storage.getSetting("apikey")+"&images=1&url="+articleUrl;
-    var url="http://text.readitlaterlist.com/v2/text";
+    var url="https://text.readitlaterlist.com/v2/text";
     xhr.open("POST", url);
     xhr.setRequestHeader("Content-type", "application/x-www-form-urlencoded");
     xhr.setRequestHeader("Content-length", params.length);
@@ -96,7 +99,13 @@ function rilDownloadRilArticle(articleUrl) {
     xhr.onreadystatechange = function() {
         if (xhr.readyState == XMLHttpRequest.DONE) {
             //console.log(xhr.responseText)
-            Storage.updateRilArticle(articleUrl,'<html><head></head><body bgcolor="#ffffff">'+xhr.responseText+'</body></html>');
+            Storage.updateRilArticle(articleUrl,'<html><head></head><body bgcolor="#ffffff">'
+                                     +'<table style="border: 1px solid darkblue; width: 100%; background-color: lightgrey">'
+                                     +'<tr><td>'
+                                     +'<a href="'+articleUrl+'">'+Storage.getRilTitle(articleUrl)+'</a>'
+                                     +'</td></tr>'
+                                     +'</table>'
+                                     +xhr.responseText+'</body></html>');
             //console.log("Finished downloading "+articleUrl)
             if (Storage.getListOfDownloadables().rows.length == 0) {
                 toolBar.feedUpdating = false;
@@ -152,25 +161,28 @@ function rilGet(listmodel) {
     //Get the list of articles in the RIL account, and add it to a ListModel object
     //var listmodel = Qt.createQmlObject('import Qt 4.7; ListModel {}', articleViewer);
     //var params = rilGetParams();
-    var xml = Storage.getRilList();
+
+    Storage.getRilList(listmodel);
     //console.log(xml);
-    if (xml=="Error") {
-          return ""
-    }
-    return xml;
+//    if (xml=="Error") {
+//          return ""
+//    }
+    return listmodel;
 }
 
 function rilMarkAsRead(item) {
     // Mark an item as read. Parameter should be the URL of the item
     var params = rilGetParams();
-    var url = "http://readitlaterlist.com/v2/send";
+    var url = "https://readitlaterlist.com/v2/send";
     
     var req = {"0" : { "url" : item } };
     var jreq = JSON.stringify(req);
+    console.log(jreq)
 
     params = params + "&read=" + jreq;
     sendReq(url, params);
-    Storage.markRilArticleAsRead(url)
+    Storage.markRilArticleAsRead(item);
+    //articleViewer.refreshList();
 }
 
 function updateList() {
@@ -179,7 +191,7 @@ function updateList() {
 
 function checkLogin() {
     var params = rilGetParams();
-    var url = "http://readitlaterlist.com/v2/auth"
+    var url = "https://readitlaterlist.com/v2/auth"
     //console.log(params)
 
     var status = sendReq(url,params);
